@@ -169,6 +169,18 @@ fn is_allowed(path: &Path, allow_list: Option<&[MatchType]>) -> bool {
     }
 }
 
+const S_IFLNK: u32 = 0o120000; // symbolic link
+
+fn is_symlink(file: &zip::read::ZipFile) -> bool {
+    if let Some(mode) = file.unix_mode() {
+        if mode & S_IFLNK == S_IFLNK {
+            return true;
+        }
+    }
+
+    false
+}
+
 pub fn download_and_extract_packages(
     install_dir: &str,
     host_os: HostOs,
@@ -230,16 +242,40 @@ pub fn download_and_extract_packages(
                             }
                         }
 
-                        let mut outfile = std::fs::File::create(&outpath).unwrap();
-                        std::io::copy(&mut file, &mut outfile).unwrap();
-                    }
-                }
+                        // adapted from https://github.com/zip-rs/zip/issues/77
+                        if is_symlink(&file) {
+                            let mut contents = Vec::new();
+                            file.read_to_end(&mut contents).unwrap();
 
-                #[cfg(unix)]
-                {
-                    use std::os::unix::fs::PermissionsExt;
-                    if let Some(mode) = file.unix_mode() {
-                        std::fs::set_permissions(&outpath, std::fs::Permissions::from_mode(mode)).unwrap();
+                            #[cfg(target_family = "unix")]
+                            {
+                                // Needed to be able to call `OsString::from_vec(Vec<u8>)`
+                                use std::os::unix::ffi::OsStringExt as _;
+
+                                let link_path = std::path::PathBuf::from(
+                                    std::ffi::OsString::from_vec(contents),
+                                );
+                                std::os::unix::fs::symlink(link_path, &outpath).unwrap();
+                            }
+
+                            #[cfg(target_family = "windows")]
+                            {
+                                // TODO: Support non-UTF-8 paths (currently only works for paths which are valid UTF-8)
+                                let link_path = String::from_utf8(contents).unwrap();
+                                std::os::windows::fs::symlink_file(link_path, &outpath).unwrap();
+                            }
+                        } else {
+                            let mut outfile = std::fs::File::create(&outpath).unwrap();
+                            std::io::copy(&mut file, &mut outfile).unwrap();
+            
+                            #[cfg(unix)]
+                            {
+                                use std::os::unix::fs::PermissionsExt;
+                                if let Some(mode) = file.unix_mode() {
+                                    std::fs::set_permissions(&outpath, std::fs::Permissions::from_mode(mode)).unwrap();
+                                }
+                            }
+                        }
                     }
                 }
             }
